VeraCrypt
aboutsummaryrefslogtreecommitdiff
path: root/src/Build/build_veracrypt_macosx.sh
diff options
context:
space:
mode:
Diffstat (limited to 'src/Build/build_veracrypt_macosx.sh')
-rwxr-xr-xsrc/Build/build_veracrypt_macosx.sh8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/Build/build_veracrypt_macosx.sh b/src/Build/build_veracrypt_macosx.sh
index f8146422..ba325d4b 100755
--- a/src/Build/build_veracrypt_macosx.sh
+++ b/src/Build/build_veracrypt_macosx.sh
@@ -12,8 +12,8 @@ SOURCEPATH=$(cd "$(dirname "$SCRIPTPATH/../.")"; pwd)
# directory where the VeraCrypt project has been checked out
PARENTDIR=$(cd "$(dirname "$SCRIPTPATH/../../../.")"; pwd)
-# the sources of wxWidgets 3.0.2 must be extracted to the parent directory
-export WX_ROOT=$PARENTDIR/wxWidgets-3.0.2
+# the sources of wxWidgets 3.0.3 must be extracted to the parent directory
+export WX_ROOT=$PARENTDIR/wxWidgets-3.0.3
echo "Using wxWidgets sources in $WX_ROOT"
# this will be the temporary wxWidgets directory
@@ -27,7 +27,7 @@ echo "Using MacOSX SDK $VC_OSX_TARGET"
cd $SOURCEPATH
echo "Building VeraCrypt"
-make WXSTATIC=1 wxbuild && make WXSTATIC=1 clean && make WXSTATIC=1
+make WXSTATIC=1 wxbuild && make WXSTATIC=1 clean && make WXSTATIC=1 && make WXSTATIC=1 package
# Uncomment below and comment line above to reuse existing wxWidgets build
# make WXSTATIC=1 clean && make WXSTATIC=1
@@ -27,7 +27,7 @@ echo "Using MacOSX SDK $VC_OSX_TARGET"
# Uncomment below and comment line above to reuse existing wxWidgets build
-# make WXSTATIC=1 clean && make WXSTATIC=1
+# make WXSTATIC=1 clean && make WXSTATIC=1 && make WXSTATIC=1 package